# Load main library
library(hivEstimatesAccuracy)
library(shiny)
library(ggplot2)

# Define input data path
inputDataFilePath <- "D:/Drive/Projects/19. PZH/Scripts/Received/20180111/DE.csv"

# Read input data
originalData <- ReadDataFile(inputDataFilePath)

# Pre-process data
defaultValues <- GetPreliminaryDefaultValues()

attrMapping <- GetPreliminaryAttributesMapping(originalData)
if (is.null(attrMapping[["FirstCD4Count"]])) {
  attrMapping[["FirstCD4Count"]] <- "cd4_num"
}

attrMappingStatus <- GetAttrMappingStatus(attrMapping)

if (attrMappingStatus$Valid) {
  inputDataTest <- ApplyAttributesMapping(originalData, attrMapping, defaultValues)
  inputDataTestStatus <- GetInputDataValidityStatus(inputDataTest)
  if (inputDataTestStatus$Valid) {
    inputData <- inputDataTest
  } else {
    inputData <- NULL
  }
} else {
  inputData <- NULL
}

inputData <- PreProcessInputData(inputData)

summaryArtifacts <- GetDataSummaryArtifacts(inputData)

# Read adjustment specifications. Take a specific one, "Multiple imputation"
adjustmentFilePaths <- GetAdjustmentSpecFileNames()
adjustmentSpecs <- list(
  # GetListObject(adjustmentFilePaths["Multiple Imputations (mice)"]),
  # GetListObject(adjustmentFilePaths["Multiple Imputations (jomo)"])
  GetListObject(adjustmentFilePaths["Reporting Delays"])
)

# Run adjustments
adjustedData <- RunAdjustments(data = inputData,
                               adjustmentSpecs = adjustmentSpecs)

intermReport <- ""
for (i in seq_along(adjustmentSpecs)) {
  intermReport <- paste(intermReport,
                        RenderReportForAdjSpec(adjustmentSpec = adjustmentSpecs[[i]],
                                               fileNameSuffix = "intermediate",
                                               params = adjustedData[[i]]))
}
intermReport <- HTML(intermReport)

# Create report
reportFilePaths <- GetReportFileNames()
params <- list(AdjustedData = adjustedData)

reportFileName <- RenderReportToFile(filePath = reportFilePaths["Multiple Imputations"],
                                     format = "html_fragment",
                                     params = params)

reportFileName <- RenderReportToFile(filePath = reportFilePaths["Multiple Imputations"],
                                     format = "html_document",
                                     params = params)

reportFileName <- RenderReportToFile(filePath = reportFilePaths["Multiple Imputations"],
                                     format = "pdf_document",
                                     params = params)

reportFileName <- RenderReportToFile(filePath = reportFilePaths["Multiple Imputations"],
                                     format = "word_document",
                                     params = params)

# Take the last adjustment output as final data
finalData <- adjustedData[[length(adjustedData)]]

# Write output
outputDataFilePath <- CreateOutputFileName(inputDataFilePath,
                                           suffix = paste0("_", GetTimeStamp()))
WriteDataFile(finalData$Table, outputDataFilePath)
